@@ -22,18 +22,21 @@ test_that("using shorthand parameters returns the same result", {
   expect_identical(dd, dd2)
 })
 
-reset_cached_files("ava")
-reset_cached_files("deps")
-reset_cached_files("desc")
-
-vcr::use_cassette("deepdep-1", {
-  test_that("obtaining Bioc dependencies returns objects of correct types", {
-    dd <- deepdep_wrapped("les", downloads = FALSE, bioc = TRUE, depth = 1, dependency_type = c("Depends", "Imports", "Enhances", "LinkingTo"))
-    expect_is(dd, "deepdep")
-  })
+test_that("obtaining Bioc dependencies returns objects of correct types", {
+  skip_if_not_installed("vcr")
+  
+  reset_cached_files("ava")
+  reset_cached_files("deps")
+  reset_cached_files("desc")
+  
+  vcr::use_cassette("deepdep-1", {
+    dd <- deepdep_wrapped("les", downloads = FALSE, bioc = TRUE, depth = 1,
+                          dependency_type = c("Depends", "Imports", "Enhances", "LinkingTo"))
+  }, serialize_with = "json")
+  
+  expect_is(dd, "deepdep")
 })
 
-
 test_that("incorrect combination of parameters results in error",{
   expect_error(deepdep_wrapped("ggforce", downloads = TRUE, local =  FALSE, bioc = TRUE, depth = 2, dependency_type = c("Depends", "Imports")))
   expect_error(deepdep_wrapped("ggforce", downloads = TRUE, local =  TRUE, bioc = TRUE, depth = 2, dependency_type = c("Depends", "Imports")))
@@ -41,12 +44,14 @@ test_that("incorrect combination of parameters results in error",{
   expect_error(deepdep("ggforce", downloads = TRUE, local =  TRUE, bioc = FALSE, depth = 2, dependency_type = c("Depends", "Imports")))
 })
 
-reset_cached_files("ava")
-reset_cached_files("deps")
-reset_cached_files("desc")
-
-vcr::use_cassette("deepdep-2", {
-  test_that("packages with no dependencies return empty deepdep object in result", {
+test_that("packages with no dependencies return empty deepdep object in result", {
+  skip_if_not_installed("vcr")
+  
+  reset_cached_files("ava")
+  reset_cached_files("deps")
+  reset_cached_files("desc")
+  
+  vcr::use_cassette("deepdep-2", {
     dd <- deepdep("rlang")
     expect_equal(nrow(dd), 0)
   })
